==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Input/flac/translations/flac_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>FLAC įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>FLAC bylos</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="151"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Apie FLAC audio įskiepį</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="152"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC audio įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="153"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov  &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Length</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Sample rate</source>
        <translation>Dažnis</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Channels</source>
        <translation>Kanalai</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>Bitrate</source>
        <translation>Kokybė</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="86"/>
        <source>File size</source>
        <translation>Bylos dydis</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="86"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp-0.5.2.tar.bz2: qmmp-0.5.2/src/plugins/Input/flac/translations/flac_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>FLAC įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>FLAC bylos</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="172"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Apie FLAC audio įskiepį</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="173"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC audio įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="174"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov  &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Length</source>
        <translation>Trukmė</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Sample rate</source>
        <translation>Dažnis</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>Channels</source>
        <translation>Kanalai</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>Bitrate</source>
        <translation>Kokybė</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>File size</source>
        <translation>Bylos dydis</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
